
#include <digitalSTROM/ds485-socket-server.h>
#include <digitalSTROM/ds485-socket-interface.h>
#include "ds485-client-interface.h"

const char *cmd2text(int opcode)
{
    switch(opcode) {
    case DS485D_CMD_API_REVISION:
        return "API_REVISION";
    case DS485D_CMD_PING:
        return "PING";
    case DS485D_CMD_TX_PACKET:
        return "TX_PACKET";
    case DS485N_CMD_LONG_TX_PACKET:
        return "LONG_TX_PACKET";
    case DS485D_CMD_RX_PACKET:
        return "RX_PACKET";
    case DS485N_CMD_LONG_RX_PACKET:
        return "LONG_RX_PACKET";
    case DS485D_CMD_DEVICE_PACKET:
        return "DEVICE_PACKET";
    case DS485N_CMD_LONG_DEVICE_PACKET:
        return "LONG_DEVICE_PACKET";
    case DS485D_CMD_REGISTER:
        return "REGISTER";
    case DS485D_CMD_UNREGISTER:
        return "UNREGISTER";
    case DS485D_CMD_PACKETFILTER:
        return "PACKETFILTER";
    case DS485D_CMD_RAWMODE:
        return "RAWMODE";
    case DS485D_CMD_QUERY_DEVICES:
        return "QUERY_DEVICE";
    case DS485D_CMD_QUERY_DSUID:
        return "QUERY_DSUID";
    case DS485D_CMD_QUERY_ADDRESS:
        return "QUERY_ADDRESS";
    case DS485D_CMD_QUERY_BUSSTATE:
        return "QUERY_BUSSTATE";
    case DS485D_CMD_BUS_CHANGE:
        return "BUS_CHANGE";
    case DS485D_CMD_BUS_STATE:
        return "BUS_STATE";
    case DS485D_CMD_RESTART_BUS:
        return "RESTART_BUS";
    default:
        return "UNKNOWN";
    }
}


/**
 * gettext not supported, check ds-assistant for translations
 */
#define _(x)    (x)

const char *ds485c_strerror(int errno)
{
    /*
     * HACK, error might not fit into ds485c_error_t but casting to it in the
     * switch will produce a warning, in case somebody adds an error type
     * without also describing it here
     */
    switch ((ds485c_error_t)errno) {
    case DS485C_ERROR_OK:
        return _("OK");
    case ERROR_SYNC_RESPONSE_TIMEOUT:
        return _("device response timeout");
    case ERROR_RESPONSE_TIMEOUT:
        return _("response timeout");
    case NOTICE_CALL_TO_BROADCAST:
        return _("broadcast call");
    case ERROR_INVALID_HANDLE:
        return _("invalid socket handle");
    case ERROR_INVALID_CONNSPEC:
        return _("invalid connection data");
    case ERROR_THREAD_START_FAILED:
        return _("thread startup failed");
    case ERROR_NO_PORT_FOUND:
        return _("network startup failed: no port found");
    case ERROR_INVALID_ADDRESS:
        return _("network startup failed: invalid address");
    case ERROR_CREATE_SOCKET:
        return _("network startup failed: no socket");
    case ERROR_SOCKET_OPTIONS:
        return _("network startup failed: setting socket options");
    case ERROR_SOCKET_CONNECT:
        return _("network connect failed");
    case ERROR_SOCKET_FULL:
        return _("network failure: socket full");
    case ERROR_SOCKET_FAILED:
        return _("dS485c: network failure: socket write failed");
    case ERROR_WAITQ_USAGE:
        return _("dS485c: incorrect use of waitqueue");
    case ERROR_INVALID_FD:
        return _("invalid descriptor");
    case ERROR_INVALID_PARAMETER:
        return _("invalid parameter");
    case ERROR_REC_WRONG_FUNCTION_ID:
        return _("wrong function id");
    case ERROR_REC_WRONG_MODIFIER:
        return _("wrong modifier");
    case ERROR_DSUID_CONVERSION:
        return _("DSUID conversion");
    }
    return _("Unknown error");
}
